#!/bin/bash

############################################################
# script per l'installazione delle stampanti di Dipartimento
# contatti: m.alessandrini@univpm.it
############################################################


PPDDIR="https://dii.univpm.it/wp-content/uploads/sites/7/2025/01"

if [ "$(id -u)" != "0" ]; then
echo "ERRORE: richiesto utente root (o sudo)"
exit 1
fi


echo
echo "Scegliere una stampante:"
echo
options=("q165: Canon C3826i" "q165: Kyocera FS-4300DN" "q170: Canon C3826i" "q170: Kyocera FS-4300DN")
PS3="Numero: "
select opt in "${options[@]}"
do
	case "$REPLY" in
	1 )
		PRINTERNAME="Q165_Canon_C3826i"
		PPDNAME="Canon-iR-ADV_C3325_3330-Postscript-Canon.ppd_"
		break
		;;
	2 )
		PRINTERNAME="Q165_FS-4300DN"
		PPDNAME="Kyocera_FS-4300DN.PPD_"
		break
		;;
	3 )
		PRINTERNAME="Q170_Canon_C3826i"
		PPDNAME="Canon-iR-ADV_C3325_3330-Postscript-Canon.ppd_"
		break
		;;
	4 )
		PRINTERNAME="Q170_FS-4300DN"
		PPDNAME="Kyocera_FS-4300DN.PPD_"
		break
		;;
	* )
		echo "???"
		;;
	esac
done


echo
echo "######################################################"
echo "                    AVVERTENZA"
echo "Per eventuali problemi riscontrati con l'installazione"
echo "della stampante, rimuovere la stampante con il comando"
echo "lpadmin -x $PRINTERNAME"
echo "oppure dall'interfaccia web di configurazione di CUPS"
echo "all'URL http://localhost:631"
echo
echo "riferimento: m.alessandrini@univpm.it"
echo "######################################################"
echo


# check that needed programs exist
if ! type wget &> /dev/null; then
echo "ERRORE: wget richiesto ma non installato"
exit 1
fi
if ! type smbclient &> /dev/null; then
echo "ERRORE: smbclient richiesto ma non installato"
exit 1
fi
if ! type lpadmin &> /dev/null; then
echo "ERRORE: lpadmin richiesto ma non installato"
exit 1
fi


# add line to /etc/samba/lmhosts if not present
grep -qs DII-PAPERCUT /etc/samba/lmhosts || echo "193.205.129.100 DII-PAPERCUT" >> /etc/samba/lmhosts


# download PPD file
echo "Download file PPD..."
if ! wget -q "$PPDDIR/$PPDNAME.zip" -O /tmp/printer-ppd.zip --no-check-certificate ; then
echo "Errore download!"
exit 1
fi
unzip /tmp/printer-ppd.zip -d /tmp


# ask username and password
echo
echo "Inserire le credenziali di Ateneo"
echo "(tipicamente P00xxxx o S00xxxx)"
echo
echo -n "Username: "
read USERNAME
echo -n "Password: "
read PASSWORD


# try to add printer
URI="smb://univpm.intra/$USERNAME:$PASSWORD@193.205.129.100/$PRINTERNAME"
lpadmin -p $PRINTERNAME -E -v $URI -P "/tmp/$PPDNAME" || exit 1
cupsaccept $PRINTERNAME || exit 1
cupsenable $PRINTERNAME || exit 1

echo "Ok!"

